@@ -186,14 +186,17 @@ class Scraper(threading.Thread):
         req = urllib2.Request(link, headers={'Range':"byte=0-{0}".format(filesize)})
         success = True
         filetype = ""
-        #try:
-        if True:
+        try:
+            #try:
             payload = urllib2.urlopen(req,timeout=5).read(filesize)
+            #except Exception, e:
+            #    if self.DEBUG:
+            #        print "typelink(): an error occured: {0}".format(str(e))
             # record bandwidth used
             self.status['bandwidth'] += filesize
             filetype = magic.from_buffer(payload,mime=True)
-        #except Exception, e:
-        #    success = False;
+        except Exception, e:
+            success = False;
         return success,filetype
 
     def checkmatch(self,siteurl,link):
@@ -215,7 +218,10 @@ class Scraper(threading.Thread):
         if linktype != "text/html":
             return False,links
         try:
+            #try:
             html = urllib2.urlopen(url)
+            #except Exception, e:
+            #    print "getpagelinks(): urllib2 error: '{0}'".format(str(e))
             # record bandwidth used
             self.status['bandwidth'] += len(str(html))
             soup = BeautifulSoup(html)
@@ -252,8 +258,8 @@ class Scraper(threading.Thread):
         except Exception, e:
             links = []
             sucess = False
-            if self.DEBUG:
-                print "An error occurred in getpagelinks(): {0}".format(str(e))
+            #if self.DEBUG:
+            #    print "An error occurred in getpagelinks(): {0}".format(str(e))
         self.status['linkcount'] += len(links)
         return success,links
 
